Learn R Programming

CORElearn (version 1.48.0)

testCore: Verification of the CORElearn installation

Description

Performs a partial check of the classification part of CORElearn.

Usage

testCoreClass(continue=TRUE) testCoreAttrEval(continue=TRUE) testCoreReg(continue=TRUE) testCoreOrdEval(continue=TRUE) testCoreNA(continue=TRUE) testCoreRPORT(continue=TRUE) testCoreRand(continue=TRUE) allTests(continue=TRUE, timed=FALSE)

Arguments

continue
Logical. Whether a warning or an error should be generated when a test fails.
timed
Logical. Whether the time usage should be printed.

Value

The functions have no output value. The result OK or FAILED is printed.

Details

Functions testCoreClass(), testCoreAttrEval(), testCoreReg() run functions CoreModel(), predict.CoreModel(), modelEval(), and attrEval() and perform a partial check of the obtained results.

Function testNA() performs a test of consistency NA and NaN between R and CORElearn.

Functions testCoreRPORT() and testCoreRand() test, whether the R_PORT directive is defined in C code and whether R random number generator is used. These tests are mostly for debugging.

Function allTests() calls all the above functions and prints a table of the results. If an error is found, a more detailed information is printed and the continuation of the tests depends on the argument continue.

See Also

CORElearn.

Examples

Run this code
allTests() # run all tests and generate an error, if any of the tests fails

Run the code above in your browser using DataLab