Learn R Programming

CORElearn (version 1.48.0)

infoCore: Description of certain CORElearn parameters

Description

Depending on parameter what the function prints some information on CORElearn, for example codes of available classification (or regression) attribute evaluation heuristics. For more complete description of the parameters see helpCore.

Usage

infoCore(what=c("attrEval","attrEvalReg"))

Arguments

what
Selects the info to be printed.

Value

For what="attrEval" or "attrEvalReg" function returns vector of codes for all implemented classification or regression attribute evaluation heuristics, respectively.

Details

Depending on the parameter what the function some information on CORElearn.

See Also

attrEval, helpCore, CoreModel.

Examples

Run this code
estClass <- infoCore(what="attrEval")
print(estClass)
infoCore(what="attrEvalReg")

Run the code above in your browser using DataLab